@@ -69,7 +69,7 @@ void DeclarativeMimeData::setUrl(const QUrl &url)
     QList<QUrl> urlList;
     urlList.append(url);
     QMimeData::setUrls(urlList);
-    emit urlChanged();
+    Q_EMIT urlChanged();
 }
 
 QJsonArray DeclarativeMimeData::urls() const
@@ -90,7 +90,7 @@ void DeclarativeMimeData::setUrls(const QJsonArray &urls)
         urlList << varUrl.toUrl();
     }
     QMimeData::setUrls(urlList);
-    emit urlsChanged();
+    Q_EMIT urlsChanged();
 }
 
 // color
@@ -112,7 +112,7 @@ void DeclarativeMimeData::setColor(const QColor &color)
 {
     if (this->color() != color) {
         this->setColorData(color);
-        emit colorChanged();
+        Q_EMIT colorChanged();
     }
 }
 
@@ -142,7 +142,7 @@ void DeclarativeMimeData::setSource(QQuickItem* source)
 {
     if (m_source != source) {
         m_source = source;
-        emit sourceChanged();
+        Q_EMIT sourceChanged();
     }
 }
 
